@@ -52,7 +52,7 @@ void XC(gga_x_2d_b88_set_params)(XC(func_type) *p, FLOAT beta)
 
 static inline void 
 func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
   FLOAT f1, f2, df1, df2, d2f1, d2f2;
   FLOAT beta, csi;
@@ -62,13 +62,13 @@ func(const XC(func_type) *p, int order, FLOAT x,
   csi  = 8.0; /* for harmonic potentials */
 
   f1 = beta/X_FACTOR_2D_C*x*x;
-  f2 = 1.0 + csi*beta*x*asinh(x);
+  f2 = 1.0 + csi*beta*x*ASINH(x);
   *f = 1.0 + f1/f2;
 
   if(order < 1) return;
 
   df1 = 2.0*beta/X_FACTOR_2D_C*x;
-  df2 = csi*beta*(asinh(x) + x/SQRT(1.0 + x*x));
+  df2 = csi*beta*(ASINH(x) + x/SQRT(1.0 + x*x));
 
   *dfdx = (df1*f2 - f1*df2)/(f2*f2);
 
