@@ -37,9 +37,9 @@ gga_x_airy_init(XC(func_type) *p)
 }
 
 
-static inline void 
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+void XC(gga_x_airy_enhance)
+  (const XC(func_type) *p, int order, FLOAT x, 
+   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
   static FLOAT 
     a1  =   0.041106, 
@@ -57,6 +57,7 @@ func(const XC(func_type) *p, int order, FLOAT x,
   FLOAT   den1,   aux1,   num1,   den2,   num2;
   FLOAT  dden1,  daux1,  dnum1,  dden2,  dnum2;
   FLOAT d2den1, d2aux1, d2num1, d2den2, d2num2;
+  FLOAT d3den1, d3aux1, d3num1, d3den2, d3num2;
 
   ss = X2S*x;
   ssa2  = POW(ss, a2);
@@ -83,13 +84,13 @@ func(const XC(func_type) *p, int order, FLOAT x,
   daux1 = a3*a2*ssa2/ss;
   dden1 = a4*daux1*den1/aux1;
 
-  *dfdx  = (dnum1*den1 - num1*dden1)/(den1*den1);
+  *dfdx  = DFRACTION(num1, dnum1, den1, dden1);
 
   if(p->func == 0){
     dnum2 = -a5*a6*ssa6/ss + a7*a8*ssa8/ss;
     dden2 = a9*a10*ssa10/ss;
 
-    *dfdx += (dnum2*den2 - num2*dden2)/(den2*den2);
+    *dfdx += DFRACTION(num2, dnum2, den2, dden2);
   }
 
   *dfdx *= X2S;
@@ -98,20 +99,38 @@ func(const XC(func_type) *p, int order, FLOAT x,
 
   d2num1 = (a2 - 1.0)*dnum1/ss;
   d2aux1 = (a2 - 1.0)*daux1/ss;
-  d2den1 = a4*d2aux1*den1/aux1 + (a4 - 1.0)*daux1*dden1/aux1;
+  d2den1 = a4*den1/(aux1*aux1) * ((a4 - 1.0)*daux1*daux1 + aux1*d2aux1);
 
-  *d2fdx2 = (2.0*num1*dden1*dden1 - 2.0*den1*dden1*dnum1 - den1*num1*d2den1 + den1*den1*d2num1)/(den1*den1*den1);
+  *d2fdx2 = D2FRACTION(num1, dnum1, d2num1, den1, dden1, d2den1);
 
   if(p->func == 0){
     d2num2 = -a5*a6*(a6 - 1.0)*ssa6/(ss*ss) + a7*a8*(a8 - 1.0)*ssa8/(ss*ss);
     d2den2 = (a10 - 1.0)*dden2/ss;
 
-    *d2fdx2 += (2.0*num2*dden2*dden2 - 2.0*den2*dden2*dnum2 - den2*num2*d2den2 + den2*den2*d2num2)/(den2*den2*den2);
+    *d2fdx2 += D2FRACTION(num2, dnum2, d2num2, den2, dden2, d2den2);
   }
   
   *d2fdx2 *= X2S*X2S;
+
+  if(order < 3) return;
+
+  d3num1 = (a2 - 2.0)*d2num1/ss;
+  d3aux1 = (a2 - 1.0)*d2aux1/ss;
+  d3den1 = a4*den1/(aux1*aux1*aux1) * ((a4 - 1.0)*daux1*((a4 - 2.0)*daux1*daux1 + 3.0*aux1*d2aux1) + aux1*aux1*d3aux1);
+
+  *d3fdx3 = D3FRACTION(num1, dnum1, d2num1, d3num1, den1, dden1, d2den1, d3den1);
+
+  if(p->func == 0){
+    d3num2 = -a5*a6*(a6 - 1.0)*(a6 - 2.0)*ssa6/(ss*ss*ss) + a7*a8*(a8 - 1.0)*(a8 - 2.0)*ssa8/(ss*ss*ss);
+    d3den2 = (a10 - 2.0)*d2den2/ss;
+
+    *d3fdx3 += D3FRACTION(num2, dnum2, d2num2, d3num2, den2, dden2, d2den2, d3den2);
+  }
+
+  *d3fdx3 *= X2S*X2S*X2S;
 }
 
+#define func XC(gga_x_airy_enhance)
 #include "work_gga_x.c"
 
 const XC(func_info_type) XC(func_info_gga_x_airy) = {
@@ -120,7 +139,7 @@ const XC(func_info_type) XC(func_info_gga_x_airy) = {
   "Constantin et al based on the Airy gas",
   XC_FAMILY_GGA,
   "LA Constantin, A Ruzsinszky, and JP Perdew, Phys. Rev. B 80, 035125 (2009)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_airy_init,
   NULL, NULL,
@@ -134,7 +153,7 @@ const XC(func_info_type) XC(func_info_gga_x_lag) = {
   "Local Airy Gas",
   XC_FAMILY_GGA,
   "L Vitos, B Johansson, J Kollar, and HL Skriver, Phys. Rev. B 62, 10046-10050 (2000)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_airy_init,
   NULL, NULL,
