@@ -24,7 +24,7 @@
 
 void
 XC(gga_x_g96_enhance)(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
   static const FLOAT c1 = 1.0/137.0;
   FLOAT sx = SQRT(x);
@@ -38,6 +38,10 @@ XC(gga_x_g96_enhance)(const XC(func_type) *p, int order, FLOAT x,
   if(order < 2) return;
 
   *d2fdx2 = 3.0*c1/(4.0*X_FACTOR_C*sx);
+
+  if(order < 2) return;
+
+  *d3fdx3 = -3.0*c1/(8.0*X_FACTOR_C*x*sx);
 }
 
 #define func XC(gga_x_g96_enhance)
@@ -49,7 +53,7 @@ const XC(func_info_type) XC(func_info_gga_x_g96) = {
   "Gill 96",
   XC_FAMILY_GGA,
   "PMW Gill, Mol. Phys. 89, 433 (1996)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL,
   work_gga_x,
