@@ -22,9 +22,9 @@
 
 #define XC_GGA_X_HERMAN          104 /* Herman et al original GGA                  */
 
-static inline void 
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+void XC(gga_x_herman_enhance)
+  (const XC(func_type) *p, int order, FLOAT x, 
+   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
   static const FLOAT beta  = 0.003/X_FACTOR_C;
 
@@ -37,8 +37,13 @@ func(const XC(func_type) *p, int order, FLOAT x,
   if(order < 2) return;
 
   *d2fdx2 = 2.0*beta;
+
+  if(order < 3) return;
+
+  *d3fdx3 = 0.0;
 }
 
+#define func XC(gga_x_herman_enhance)
 #include "work_gga_x.c"
 
 const XC(func_info_type) XC(func_info_gga_x_herman) = {
@@ -48,7 +53,7 @@ const XC(func_info_type) XC(func_info_gga_x_herman) = {
   XC_FAMILY_GGA,
   "F Herman, JP Van Dyke, and IB Ortenburger, Phys. Rev. Lett. 22, 807 (1969)\n"
   "F Herman, IB Ortenburger, and JP Van Dyke, Int. J. Quantum Chem. Symp. 3, 827 (1970)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL,
   work_gga_x,
