@@ -126,7 +126,7 @@ func(const XC(func_type) *p, int order, FLOAT x, FLOAT ds,
 
   if(order >= 1){
     dnudrho = -nu/(3.0*ds);
-    dssdx  = X2S;
+    dssdx   = X2S;
   }
 
   /* first let us calculate H(s) */
@@ -286,7 +286,7 @@ const XC(func_info_type) XC(func_info_gga_x_hjs_b88) = {
   XC_FAMILY_GGA,
   "TM Henderson, BG Janesko, and GE Scuseria, J. Chem. Phys. 128, 194105 (2008)",
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-6, 1e-11, 0.0, 0.0, /* densities smaller than 1.1e-7 yield NaNs */
+  1e-6, 1e-11, 0.0, 0.0, /* densities smaller than 1e-6 yield NaNs */
   gga_x_hjs_init,
   NULL, NULL, 
   work_gga_x,
