@@ -52,35 +52,47 @@ XC(gga_x_optx_set_params)(XC(func_type) *p, FLOAT a, FLOAT b, FLOAT gamma)
 }
 
 
-static inline void
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+void XC(gga_x_optx_enhance)
+  (const XC(func_type) *p, int order, FLOAT x, 
+   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
   FLOAT a, b, gamma;
-  FLOAT f1, u, du, d2u;
+  FLOAT num, dnum, d2num, den, u, du, d2u, d3u;
 
   assert(p->params != NULL);
   a     = ((gga_x_optx_params *) (p->params))->a;
   b     = ((gga_x_optx_params *) (p->params))->b;
   gamma = ((gga_x_optx_params *) (p->params))->gamma;
 
-  f1 = 1.0 + gamma*x*x;
-  u  = gamma*x*x/f1;
+  num = gamma*x*x;
+  den = 1.0 + num;
+  u  = num/den;
 
-  *f     = a + b*u*u;
+  *f = a + b*u*u;
   
   if(order < 1) return;
 
-  du  = 2.0*gamma*x/(f1*f1);
+  dnum = 2.0*gamma*x;
+  du   = DFRACTION(num, dnum, den, dnum);
 
   *dfdx  = 2.0*b*u*du;
 
   if(order < 2) return;
 
-  d2u = 2.0*gamma/(f1*f1)*(1.0 - 4.0*gamma*x*x/f1);
+  d2num = 2.0*gamma;
+  d2u   = D2FRACTION(num, dnum, d2num, den, dnum, d2num);
+
   *d2fdx2 = 2.0*b*(du*du + u*d2u);
+
+  if(order < 3) return;
+
+  d3u = D3FRACTION(num, dnum, d2num, 0.0, den, dnum, d2num, 0.0);
+
+  *d3fdx3 = 2.0*b*(3.0*du*d2u + u*d3u);
 }
 
+
+#define func XC(gga_x_optx_enhance)
 #include "work_gga_x.c"
 
 const XC(func_info_type) XC(func_info_gga_x_optx) = {
@@ -89,7 +101,7 @@ const XC(func_info_type) XC(func_info_gga_x_optx) = {
   "Handy & Cohen OPTX 01",
   XC_FAMILY_GGA,
   "NC Handy and AJ Cohen, Mol. Phys. 99, 403 (2001)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_optx_init,
   NULL, NULL,
