@@ -26,41 +26,55 @@
 #define XC_GGA_X_PBE_SOL      116 /* Perdew, Burke & Ernzerhof exchange (solids)    */
 #define XC_GGA_X_XPBE         123 /* xPBE reparametrization by Xu & Goddard         */
 #define XC_GGA_X_PBE_JSJR     126 /* JSJR reparametrization by Pedroza, Silva & Capelle */
-#define XC_GGA_X_PBEK1_VDW    140 /* PBE reparametrization for vdW */
-#define XC_GGA_X_RGE2         142 /* Regularized PBE */
+#define XC_GGA_X_PBEK1_VDW    140 /* PBE reparametrization for vdW                  */
+#define XC_GGA_X_RGE2         142 /* Regularized PBE                                */
 #define XC_GGA_X_APBE         184 /* mu fixed from the semiclassical neutral atom   */
+#define XC_GGA_X_PBEINT        60 /* PBE for hybrid interfaces                      */
+#define XC_GGA_X_PBE_TCA       59 /* PBE revised by Tognetti et al                  */
 #define XC_GGA_K_APBE         185 /* mu fixed from the semiclassical neutral atom   */
 #define XC_GGA_K_TW1          187 /* Tran and Wesolowski set 1 (Table II)           */
 #define XC_GGA_K_TW2          188 /* Tran and Wesolowski set 2 (Table II)           */
 #define XC_GGA_K_TW3          189 /* Tran and Wesolowski set 3 (Table II)           */
 #define XC_GGA_K_TW4          190 /* Tran and Wesolowski set 4 (Table II)           */
-
+#define XC_GGA_K_REVAPBE       55 /* revised APBE                                   */
+#define XC_GGA_K_APBEINT       54 /* interpolated version of APBE                   */
+#define XC_GGA_K_REVAPBEINT    53 /* interpolated version of REVAPBE                */
+#define XC_GGA_X_PBE_MOL       49 /* Del Campo, Gazquez, Trickey and Vela (PBE-like) */
 
 typedef struct{
   FLOAT kappa, mu;
+
+  /* parameters only used for PBEint and similar functionals */
+  FLOAT alpha, muPBE, muGE;
 } gga_x_pbe_params;
 
 
 static void 
 gga_x_pbe_init(XC(func_type) *p)
 {
-  static const FLOAT kappa[13] = {
+  static const FLOAT kappa[19] = {
     0.8040,  /* original PBE */
-    1.245,   /* PBE R     */
-    0.8040,  /* PBE sol   */
-    0.91954, /* xPBE      */
-    0.8040,  /* PBE_JSJR  */
-    1.0,     /* PBEK1_VDW */
-    0.8040,  /* RGE2      */
-    0.8040,  /* APBE (X)  */
-    0.8040,  /* APBE (K)  */
-    0.8209,  /* TW1       */
-    0.6774,  /* TW2       */
-    0.8438,  /* TW3       */
-    0.8589   /* TW4       */
+    1.245,   /* PBE R       */
+    0.8040,  /* PBE sol     */
+    0.91954, /* xPBE        */
+    0.8040,  /* PBE_JSJR    */
+    1.0,     /* PBEK1_VDW   */
+    0.8040,  /* RGE2        */
+    0.8040,  /* APBE (X)    */
+    0.8040,  /* APBE (K)    */
+    0.8209,  /* TW1         */
+    0.6774,  /* TW2         */
+    0.8438,  /* TW3         */
+    0.8589,  /* TW4         */
+    0.8040,  /* PBEint      */
+    1.227,   /* PBE TCA     */
+    1.245,   /* revAPBE (K) */
+    0.8040,  /* APBEINT (K) */
+    1.245,   /* revAPBEINT (K) */
+    0.8040   /* PBEmol    */
   };
 
-  static const FLOAT mu[13] = {
+  static const FLOAT mu[19] = {
     0.2195149727645171,     /* PBE: mu = beta*pi^2/3, beta = 0.06672455060314922 */
     0.2195149727645171,     /* PBE rev: as PBE */
     10.0/81.0,              /* PBE sol */
@@ -73,12 +87,25 @@ gga_x_pbe_init(XC(func_type) *p)
     0.2335,                 /* TW1       */
     0.2371,                 /* TW2       */
     0.2319,                 /* TW3       */
-    0.2309                  /* TW4       */
+    0.2309,                 /* TW4       */
+    0.0,                    /* PBEint (to be set later) */
+    0.2195149727645171,     /* PBE TCA: as PBE */
+    0.23889,                /* revAPBE (K)  */
+    0.0,                    /* APBEINT (K) (to be set later) */
+    0.0,                    /* REVAPBEINT (K) (to be set later) */
+    0.27583                 /* PBEmol    */
   };
 
+  gga_x_pbe_params *params;
+
   assert(p!=NULL && p->params == NULL);
   p->params = malloc(sizeof(gga_x_pbe_params));
+  params = (gga_x_pbe_params *) (p->params);
  
+  params->alpha = 0.0;
+  params->muPBE = 0.0;
+  params->muGE  = 0.0;
+
   switch(p->info->number){
   case XC_GGA_X_PBE:        p->func = 0;  break;
   case XC_GGA_X_PBE_R:      p->func = 1;  break;
@@ -93,10 +120,34 @@ gga_x_pbe_init(XC(func_type) *p)
   case XC_GGA_K_TW2:        p->func = 10; break;
   case XC_GGA_K_TW3:        p->func = 11; break;
   case XC_GGA_K_TW4:        p->func = 12; break;
-  default:
+  case XC_GGA_X_PBEINT: {
+    p->func  = 13;
+    params->alpha = 0.197;
+    params->muPBE = 0.2195149727645171;
+    params->muGE  = 10.0/81.0;
+    break;
+  }
+  case XC_GGA_X_PBE_TCA:    p->func = 14; break;
+  case XC_GGA_K_REVAPBE:    p->func = 15; break;
+  case XC_GGA_K_APBEINT: {
+    p->func  = 16;
+    params->alpha = 5.0/3.0;
+    params->muPBE = 0.23899;
+    params->muGE  = 5.0/27.0;
+    break;
+  }
+  case XC_GGA_K_REVAPBEINT: { /* equal to the previous one */
+    p->func  = 17;
+    params->alpha = 5.0/3.0;
+    params->muPBE = 0.23899;
+    params->muGE  = 5.0/27.0;
+    break;
+  }
+  case XC_GGA_X_PBE_MOL:    p->func = 18; break;
+  default:{
     fprintf(stderr, "Internal error in gga_x_pbe\n");
     exit(1);
-  }
+  }}
 
   XC(gga_x_pbe_set_params)(p, kappa[p->func], mu[p->func]);
 }
@@ -117,17 +168,25 @@ XC(gga_x_pbe_set_params)(XC(func_type) *p, FLOAT kappa, FLOAT mu)
 
 void XC(gga_x_pbe_enhance) 
   (const XC(func_type) *p, int order, FLOAT x, 
-   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
-  FLOAT kappa, mu, ss, ss2, f0, df0, d2f0;
+  gga_x_pbe_params *params;
+  FLOAT kappa, auxmu, mu, dmu, d2mu, d3mu, ss, ss2, f0, df0, d2f0, d3f0;
 
   assert(p->params != NULL);
-  kappa = ((gga_x_pbe_params *) (p->params))->kappa;
-  mu    = ((gga_x_pbe_params *) (p->params))->mu;
+  params = (gga_x_pbe_params *) (p->params);
+
+  kappa = params->kappa;
 
   ss  = X2S*x;
   ss2 = ss*ss;
  
+  if(params->alpha != 0.0){ /* PBEint and related functionals */
+    auxmu = 1.0 + params->alpha*ss2;
+    mu = params->muGE + (params->muPBE - params->muGE) * params->alpha*ss2/auxmu;
+  }else
+    mu = params->mu;
+
   f0 = kappa + mu*ss2;
   if(p->info->number == XC_GGA_X_RGE2)
     f0 += mu*mu*ss2*ss2/kappa;
@@ -136,7 +195,12 @@ void XC(gga_x_pbe_enhance)
 
   if(order < 1) return;
 
-  df0 = 2.0*mu*ss;
+  if(params->alpha != 0.0){ /* PBEint and related functionals */
+    dmu = (params->muPBE - params->muGE) * 2.0*params->alpha*ss/(auxmu*auxmu);
+  }else
+    dmu = 0.0;
+
+  df0 = 2.0*mu*ss + dmu*ss2;
   if(p->info->number == XC_GGA_X_RGE2)
     df0 += 4.0*mu*mu*ss2*ss/kappa;
 
@@ -144,11 +208,32 @@ void XC(gga_x_pbe_enhance)
 
   if(order < 2) return;
 
-  d2f0 = 2.0*mu;
+  if(params->alpha != 0.0) /* PBEint and related functionals */
+    d2mu = (params->muPBE - params->muGE) * 
+      2.0*params->alpha*(1.0 - 3.0*params->alpha*ss2)/(auxmu*auxmu*auxmu);
+  else
+    d2mu = 0.0;
+
+  d2f0 = 2.0*mu + 4.0*dmu*ss + d2mu*ss2;
   if(p->info->number == XC_GGA_X_RGE2)
     d2f0 += 4.0*3.0*mu*mu*ss2/kappa;
 
-  *d2fdx2 = X2S*X2S*kappa*kappa/(f0*f0)*(d2f0 - 2.0*df0*df0/f0);
+  *d2fdx2 = -X2S*X2S*kappa*kappa*(2.0*df0*df0 - d2f0*f0)/(f0*f0*f0);
+
+  if(order < 3) return;
+
+  if(params->alpha != 0.0) /* PBEint and related functionals */
+    d3mu = (params->muPBE - params->muGE) * 
+      24.0*params->alpha*params->alpha*ss*(-1.0 + params->alpha*ss2)/(auxmu*auxmu*auxmu*auxmu);
+  else
+    d3mu = 0.0;  
+
+  d3f0 = 6.0*dmu + 6.0*ss*d2mu + ss2*d3mu;
+  if(p->info->number == XC_GGA_X_RGE2)
+    d3f0 += 4.0*3.0*2.0*mu*mu*ss/kappa;
+
+  *d3fdx3 = X2S*X2S*X2S*kappa*kappa*(6.0*df0*df0*df0 - 6.0*f0*df0*d2f0 + f0*f0*d3f0)/(f0*f0*f0*f0);
+  
 }
 
 
@@ -163,7 +248,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe) = {
   XC_FAMILY_GGA,
   "JP Perdew, K Burke, and M Ernzerhof, Phys. Rev. Lett. 77, 3865 (1996)\n"
   "JP Perdew, K Burke, and M Ernzerhof, Phys. Rev. Lett. 78, 1396(E) (1997)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
   NULL, NULL,
@@ -177,7 +262,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_r) = {
   "Revised PBE from Zhang & Yang",
   XC_FAMILY_GGA,
   "Y Zhang and W Yang, Phys. Rev. Lett 80, 890 (1998)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
   NULL, NULL,
@@ -191,7 +276,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_sol) = {
   "Perdew, Burke & Ernzerhof SOL",
   XC_FAMILY_GGA,
   "JP Perdew, et al, Phys. Rev. Lett. 100, 136406 (2008)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
   NULL, NULL,
@@ -205,7 +290,7 @@ const XC(func_info_type) XC(func_info_gga_x_xpbe) = {
   "Extended PBE by Xu & Goddard III",
   XC_FAMILY_GGA,
   "X Xu and WA Goddard III, J. Chem. Phys. 121, 4068 (2004)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
   NULL, NULL,
@@ -219,7 +304,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbe_jsjr) = {
   "Reparametrized PBE by Pedroza, Silva & Capelle",
   XC_FAMILY_GGA,
   "LS Pedroza, AJR da Silva, and K. Capelle, Phys. Rev. B 79, 201106(R) (2009)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
   NULL, NULL,
@@ -233,7 +318,7 @@ const XC(func_info_type) XC(func_info_gga_x_pbek1_vdw) = {
   "Reparametrized PBE for vdW",
   XC_FAMILY_GGA,
   "J Klimes, DR Bowler, and A Michaelides, J. Phys.: Condens. Matter 22, 022201 (2010)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init, 
   NULL, NULL,
@@ -247,7 +332,7 @@ const XC(func_info_type) XC(func_info_gga_x_rge2) = {
   "Regularized PBE",
   XC_FAMILY_GGA,
   "A Ruzsinszky, GI Csonka, and G Scuseria, J. Chem. Theory Comput. 5, 763 (2009)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
@@ -261,7 +346,7 @@ const XC(func_info_type) XC(func_info_gga_x_apbe) = {
   "mu fixed from the semiclassical neutral atom",
   XC_FAMILY_GGA,
   "LA Constantin, E Fabiano, S Laricchia, and F Della Sala, Phys. Rev. Lett. 106, 186406 (2011)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
@@ -269,6 +354,36 @@ const XC(func_info_type) XC(func_info_gga_x_apbe) = {
   NULL
 };
 
+const XC(func_info_type) XC(func_info_gga_x_pbeint) = {
+  XC_GGA_X_PBEINT,
+  XC_EXCHANGE,
+  "PBE for hybrid interfaces",
+  XC_FAMILY_GGA,
+  "E. Fabiano, LA Constantin, and F. Della Sala, Phys. Rev. B 82, 113104 (2010)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-12, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+
+const XC(func_info_type) XC(func_info_gga_x_pbe_tca) = {
+  XC_GGA_X_PBE_TCA,
+  XC_EXCHANGE,
+  "PBE revised by Tognetti et al",
+  XC_FAMILY_GGA,
+  "V Tognetti, P Cortona, and C Adamo, Chem. Phys. Lett. 460, 536-539 (2008)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
+
+
 #define XC_KINETIC_FUNCTIONAL
 #include "work_gga_x.c"
 
@@ -278,7 +393,21 @@ const XC(func_info_type) XC(func_info_gga_k_apbe) = {
   "mu fixed from the semiclassical neutral atom",
   XC_FAMILY_GGA,
   "LA Constantin, E Fabiano, S Laricchia, and F Della Sala, Phys. Rev. Lett. 106, 186406 (2011)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_k,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_k_revapbe) = {
+  XC_GGA_K_REVAPBE,
+  XC_KINETIC,
+  "revised APBE",
+  XC_FAMILY_GGA,
+  "LA Constantin, E Fabiano, S Laricchia, and F Della Sala, Phys. Rev. Lett. 106, 186406 (2011)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
@@ -292,7 +421,7 @@ const XC(func_info_type) XC(func_info_gga_k_tw1) = {
   "Tran and Wesolowski set 1 (Table II)",
   XC_FAMILY_GGA,
   "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
@@ -306,7 +435,7 @@ const XC(func_info_type) XC(func_info_gga_k_tw2) = {
   "Tran and Wesolowski set 1 (Table II)",
   XC_FAMILY_GGA,
   "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
@@ -320,7 +449,7 @@ const XC(func_info_type) XC(func_info_gga_k_tw3) = {
   "Tran and Wesolowski set 1 (Table II)",
   XC_FAMILY_GGA,
   "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
@@ -334,10 +463,52 @@ const XC(func_info_type) XC(func_info_gga_k_tw4) = {
   "Tran and Wesolowski set 1 (Table II)",
   XC_FAMILY_GGA,
   "F Tran and TA Wesolowski, Int. J. Quant. Chem. 89, 441-446 (2002)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_pbe_init,
   NULL, NULL,
   work_gga_k,
   NULL
 };
+
+const XC(func_info_type) XC(func_info_gga_k_apbeint) = {
+  XC_GGA_K_APBEINT,
+  XC_KINETIC,
+  "interpolated version of APBE",
+  XC_FAMILY_GGA,
+  "S Laricchia, E Fabiano, LA Constantin, and F Della Sala, J. Chem. Theory Comput. 7, 2439-2451 (2011)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_k,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_k_revapbeint) = {
+  XC_GGA_K_REVAPBEINT,
+  XC_KINETIC,
+  "interpolated version of REVAPBE",
+  XC_FAMILY_GGA,
+  "S Laricchia, E Fabiano, LA Constantin, and F Della Sala, J. Chem. Theory Comput. 7, 2439-2451 (2011)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init,
+  NULL, NULL,
+  work_gga_k,
+  NULL
+};
+
+const XC(func_info_type) XC(func_info_gga_x_pbe_mol) = {
+  XC_GGA_X_PBE_MOL,
+  XC_EXCHANGE,
+  "Reparametrized PBE by del Campo, Gazquez, Trickey & Vela",
+  XC_FAMILY_GGA,
+  "JM del Campo, JL Gazquez, SB Trickey, and A Vela, J. Chem. Phys. 136, 104108 (2012)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  gga_x_pbe_init, 
+  NULL, NULL,
+  work_gga_x,
+  NULL
+};
