@@ -57,11 +57,11 @@ XC(gga_x_ssb_sw_set_params)(XC(func_type) *p, FLOAT A, FLOAT B, FLOAT C, FLOAT D
 }
 
 
-static inline void
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+void XC(gga_x_ssb_sw_enhance)
+  (const XC(func_type) *p, int order, FLOAT x, 
+   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
-  FLOAT ss, ss2, ss4, den1, den2;
+  FLOAT ss, ss2, ss4, num1, dnum1, d2num1, num2, dnum2, d2num2, den1, dden1, d2den1, den2, dden2, d2den2, d3den2;
   gga_x_ssb_sw_params *params;
 
   assert(p != NULL && p->params != NULL);
@@ -71,23 +71,48 @@ func(const XC(func_type) *p, int order, FLOAT x,
   ss2 = ss*ss;
   ss4 = ss2*ss2;
 
+  num1 = params->B*ss2;
   den1 = 1.0 + params->C*ss2;
+
+  num2 = -params->D*ss2;
   den2 = 1.0 + params->E*ss4;
 
-  *f   = params->A + params->B*ss2/den1 - params->D*ss2/den2;
+  *f   = params->A + num1/den1 +num2/den2;
   
   if(order < 1) return;
 
-  *dfdx  = params->B*2.0*ss/(den1*den1) - params->D*2.0*ss*(1.0 - params->E*ss2*ss2)/(den2*den2);
+  dnum1 = 2.0*params->B*ss;
+  dden1 = 2.0*params->C*ss;
+
+  dnum2 = -2.0*params->D*ss;
+  dden2 = 4.0*params->E*ss*ss2;
+
+  *dfdx  = DFRACTION(num1, dnum1, den1, dden1) + DFRACTION(num2, dnum2, den2, dden2);
   *dfdx *= X2S;
 
   if(order < 2) return;
 
-  *d2fdx2  = params->B*(2.0 -6.0*params->C*ss2)/(den1*den1*den1)
-    - params->D*2.0*(1.0 - 3.0*params->E*ss4*(4.0 - params->E*ss4))/(den2*den2*den2);
+  d2num1 = 2.0*params->B;
+  d2den1 = 2.0*params->C;
+
+  d2num2 = -2.0*params->D;
+  d2den2 =  4.0*3.0*params->E*ss2;
+
+  *d2fdx2  = D2FRACTION(num1, dnum1, d2num1, den1, dden1, d2den1) + 
+    D2FRACTION(num2, dnum2, d2num2, den2, dden2, d2den2);
   *d2fdx2 *= X2S*X2S;
+
+  if(order < 3) return;
+
+  d3den2 =  4.0*3.0*2.0*params->E*ss;
+
+  *d3fdx3  = D3FRACTION(num1, dnum1, d2num1, 0.0, den1, dden1, d2den1, 0.0) + 
+    D3FRACTION(num2, dnum2, d2num2, 0.0, den2, dden2, d2den2, d3den2);
+  *d3fdx3 *= X2S*X2S*X2S;
 }
 
+
+#define func XC(gga_x_ssb_sw_enhance)
 #include "work_gga_x.c"
 
 static void
@@ -126,7 +151,7 @@ const XC(func_info_type) XC(func_info_gga_x_ssb_sw) = {
   "Swarta, Sola and Bickelhaupt correction to PBE",
   XC_FAMILY_GGA,
   "M Swart, M Sola, and FM Bickelhaupt, J. Comp. Meth. Sci. Engin. 9, 69 (2009)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   gga_x_ssb_sw_init,
   NULL, NULL,
