@@ -21,13 +21,14 @@
 #include <assert.h>
 #include "util.h"
 
-#define XC_HYB_GGA_XC_B1WC   412 /* Becke 1-parameter mixture of WC and PBE */
-#define XC_HYB_GGA_XC_B1LYP  416 /* Becke 1-parameter mixture of B88 and LYP */
-#define XC_HYB_GGA_XC_B1PW91 417 /* Becke 1-parameter mixture of B88 and PW91 */
-#define XC_HYB_GGA_XC_mPW1PW 418 /* Becke 1-parameter mixture of mPW91 and PW91 */
-#define XC_HYB_GGA_XC_mPW1K  405 /* mixture of mPW91 and PW91 optimized for kinetics */
-#define XC_HYB_GGA_XC_BHANDH 435 /* Becke half-and-half */
-#define XC_HYB_GGA_XC_BHANDHLYP 436 /* Becke half-and-half with B88 exchange*/
+#define XC_HYB_GGA_XC_B1WC      412  /* Becke 1-parameter mixture of WC and PBE          */
+#define XC_HYB_GGA_XC_B1LYP     416  /* Becke 1-parameter mixture of B88 and LYP         */
+#define XC_HYB_GGA_XC_B1PW91    417  /* Becke 1-parameter mixture of B88 and PW91        */
+#define XC_HYB_GGA_XC_mPW1PW    418  /* Becke 1-parameter mixture of mPW91 and PW91      */
+#define XC_HYB_GGA_XC_mPW1K     405  /* mixture of mPW91 and PW91 optimized for kinetics */
+#define XC_HYB_GGA_XC_BHANDH    435  /* Becke half-and-half                              */
+#define XC_HYB_GGA_XC_BHANDHLYP 436  /* Becke half-and-half with B88 exchange            */
+#define XC_HYB_GGA_XC_MPWLYP1M  453  /* MPW with 1 par. for metals/LYP                   */
 
 void
 XC(hyb_gga_xc_b1wc_init)(XC(func_type) *p)
@@ -188,3 +189,26 @@ const XC(func_info_type) XC(func_info_hyb_gga_xc_bhandhlyp) = {
   XC(hyb_gga_xc_bhandhlyp_init),
   NULL, NULL, NULL, NULL
 };
+
+
+void
+XC(hyb_gga_xc_mpwlyp1m_init)(XC(func_type) *p)
+{
+  static int   funcs_id  [2] = {XC_GGA_X_MPW91, XC_GGA_C_LYP};
+  static FLOAT funcs_coef[2] = {1.0 - 0.05, 1.0};
+
+  XC(mix_init)(p, 2, funcs_id, funcs_coef);
+  p->cam_alpha = 0.05;
+}
+
+const XC(func_info_type) XC(func_info_hyb_gga_xc_mpwlyp1m) = {
+  XC_HYB_GGA_XC_MPWLYP1M,
+  XC_EXCHANGE_CORRELATION,
+  "MPW with 1 par. for metals/LYP",
+  XC_FAMILY_HYB_GGA,
+  "NE Schultz, Y Zhao, and DG Truhlar, J. Phys. Chem. A 109, 11127-11143 (2005)",
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  1e-32, 1e-32, 0.0, 1e-32,
+  XC(hyb_gga_xc_mpwlyp1m_init),
+  NULL, NULL, NULL, NULL
+};
