@@ -212,4 +212,6 @@ const XC(func_info_type) XC(func_info_lda_c_1d_csc) = {
   lda_c_1d_csc_init,    /* init */
   NULL,                 /* end  */
   work_lda,             /* lda  */
+  NULL,
+  NULL
 };
