@@ -48,7 +48,7 @@ hl_f(int func, int order, int i, FLOAT rs, FLOAT *zk, FLOAT *drs, FLOAT *d2rs, F
   x2  = x*x;
   x3  = x2*x;
   
-  a   = log(1.0 + 1.0/x);
+  a   = LOG(1.0 + 1.0/x);
   *zk = -c[func][i]*((1.0 + x3)*a - x2 + 0.5*x - 1.0/3.0);
   
   if(order < 1) return;
